{% extends "base.html" %}

{% block title %}Upload in progress{% endblock %}

{% block content %}
<h1>Upload in progress</h1>

<p>Importing rows into
    <a href="{{ table_url }}">{{ table }}</a>
</p>
{% endblock %}
